@@ -46,6 +46,9 @@ def hunspellchecker_argument_parser(
     words_not_contain_dash=True,
     words_not_contain_dash_name_or_flags=["--words-not-contain-dash"],
     words_not_contain_dash_kwargs={},
+    words_not_contain_two_upper=True,
+    words_not_contain_two_upper_name_or_flags=["--words-not-contain-two-upper"],
+    words_not_contain_two_upper_kwargs={},
     no_include_filename=True,
     no_include_filename_name_or_flags=["--no-include-filename"],
     no_include_filename_kwargs={},
@@ -136,11 +139,11 @@ def hunspellchecker_argument_parser(
             constructing the ``-l/--language`` option.
         negotiate_languages (bool): Enables the language negotiation. If this
             is enabled and the CLI consumer passes a locale code instead of
-            a full language name (for example `es` instead of `es_ES`),
-            hunspellcheck will convert `es` to a territorialized language
+            a full language name (for example ``es`` instead of ``es_ES``),
+            hunspellcheck will convert ``es`` to a territorialized language
             dictionary name available using the function
             :py:meth:`babel.core.Locale.negotiate`. If is disabled, a language
-            dictionary passed as locale code like `es` will be considered
+            dictionary passed as locale code like ``es`` will be considered
             invalid.
         personal_dicts (bool): Include the ``-p/--personal-dict`` option inside
             the argument parser.
@@ -166,7 +169,7 @@ def hunspellchecker_argument_parser(
             :py:meth:`argparse.ArgumentParser.add_argument`.
         digits_are_words_kwargs (dict): Optional kwargs which override default
             kwargs passed to :py:meth:`argparse.ArgumentParser.add_argument`
-            building the ``--digits-are-words` option.
+            building the ``--digits-are-words`` option.
         words_not_contain_digits (bool): Include the option
             ``--words-not-contain-digits`` which when passed in a CLI, the
             words that contain digits will be ignored mispellchecking errors.
@@ -176,7 +179,7 @@ def hunspellchecker_argument_parser(
         words_not_contain_digits_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--words-not-contain-digits` option.
+            ``--words-not-contain-digits`` option.
         words_not_startswith_dash (bool): Include the option
             ``--words-not-startswith-dash`` which when passed in a CLI, the
             words starting with character ``"-" `` will be ignored
@@ -187,7 +190,7 @@ def hunspellchecker_argument_parser(
         words_not_startswith_dash_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--words-not-startswith-dash` option.
+            ``--words-not-startswith-dash`` option.
         words_not_endswith_dash (bool): Include the option
             ``--words-not-endswith-dash`` which when passed in a CLI, the
             words ending with character ``"-" `` will be ignored
@@ -198,7 +201,7 @@ def hunspellchecker_argument_parser(
         words_not_endswith_dash_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--words-not-endswith-dash` option.
+            ``--words-not-endswith-dash`` option.
         words_not_contain_dash (bool): Include the option
             ``--words-not-contain-dash`` which when passed in a CLI, the
             words containing character ``"-" `` will be ignored mispellchecking
@@ -209,7 +212,18 @@ def hunspellchecker_argument_parser(
         words_not_contain_dash_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--words-not-contain-dash` option.
+            ``--words-not-contain-dash`` option.
+        words_not_contain_two_upper (bool): Include the option
+            ``--words-not-contain-two-upper`` which when passed in a CLI, the
+            words containing two uppercase letters or mote will be ignored
+            mispellchecking for possible errors.
+        words_not_contain_two_upper_name_or_flags (list): Flag name defined
+            constructing the ``--words-not-contain-two-upper`` option using the
+            method :py:meth:`argparse.ArgumentParser.add_argument`.
+        words_not_contain_two_upper_kwargs (dict): Optional kwargs which override
+            default kwargs passed to
+            :py:meth:`argparse.ArgumentParser.add_argument` building the
+            ``--words-not-contain-two-upper`` option.
         no_include_filename (bool): Include the option
             ``--no-include-filename`` which when passed in a CLI, the path to
             files in which mispelling errors are found are not shown in
@@ -220,7 +234,7 @@ def hunspellchecker_argument_parser(
         no_include_filename_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--no-include-filename` option.
+            ``--no-include-filename`` option.
         no_include_line_number (bool): Include the option
             ``--no-include-line-number`` which when passed in a CLI, the number
             of lines in which mispelling errors are found are not shown in
@@ -231,7 +245,7 @@ def hunspellchecker_argument_parser(
         no_include_line_number_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--no-include-line-number` option.
+            ``--no-include-line-number`` option.
         no_include_word (bool): Include the option
             ``--no-include-word`` which when passed in a CLI, the words
             in which mispelling errors are found are not shown in the output.
@@ -241,7 +255,7 @@ def hunspellchecker_argument_parser(
         no_include_word_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--no-include-word` option.
+            ``--no-include-word`` option.
         no_include_word_line_index (bool): Include the option
             ``--no-include-word-line-index`` which when passed in a CLI, the
             index of the mispelled words inside their lines in which mispelling
@@ -252,7 +266,7 @@ def hunspellchecker_argument_parser(
         no_include_word_line_index_kwargs (dict): Optional kwargs which
             override default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--no-include-word-line-index` option.
+            ``--no-include-word-line-index`` option.
         include_line (bool): Include the option ``--include-line`` which when
             passed in a CLI, the line of the mispelled words in which
             mispelling errors are found are shown in the output.
@@ -261,7 +275,7 @@ def hunspellchecker_argument_parser(
             :py:meth:`argparse.ArgumentParser.add_argument`.
         include_line_kwargs (dict): Optional kwargs which override default
             kwargs passed to :py:meth:`argparse.ArgumentParser.add_argument`
-            building the ``--include-line` option.
+            building the ``--include-line`` option.
         include_text (bool): Include the option ``--include-text`` which when
             passed in a CLI, the text in which reside found mispelled words
             is shown in the output.
@@ -270,7 +284,7 @@ def hunspellchecker_argument_parser(
             :py:meth:`argparse.ArgumentParser.add_argument`.
         include_text_kwargs (dict): Optional kwargs which override default
             kwargs passed to :py:meth:`argparse.ArgumentParser.add_argument`
-            building the ``--include-text` option.
+            building the ``--include-text`` option.
         include_error_number (bool): Include the option
             ``--include-error-number`` which when passed in a CLI, the number
             of each error is shown in the output.
@@ -280,7 +294,7 @@ def hunspellchecker_argument_parser(
         include_error_number_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--include-error-number` option.
+            ``--include-error-number`` option.
         include_near_misses (bool): Include the option
             ``--include-near-misses`` which when passed in a CLI, some Hunspell
             suggestions will be shown for each mispelled word in the report.
@@ -290,9 +304,10 @@ def hunspellchecker_argument_parser(
         include_near_misses_kwargs (dict): Optional kwargs which override
             default kwargs passed to
             :py:meth:`argparse.ArgumentParser.add_argument` building the
-            ``--include-near-misses` option.
+            ``--include-near-misses`` option.
 
     Examples:
+
         >>> import argparse
         >>>
         >>> parser = argparse.ArgumentParser()
@@ -303,6 +318,7 @@ def hunspellchecker_argument_parser(
         >>> opts = parser.parse_args(["--language", "es"])
         >>> print(opts)
         Namespace(languages=["es_ES"])
+
     """
     if version:
         version_string = render_version_template(
@@ -318,7 +334,7 @@ def hunspellchecker_argument_parser(
             _version_kwargs = {"action": "version", "version": version_string}
             _version_kwargs.update(version_kwargs)
 
-            if isinstance(version_name_or_flags, str):
+            if isinstance(version_name_or_flags, str):  # pragma: no cover
                 version_name_or_flags = [version_name_or_flags]
 
             parser.add_argument(*version_name_or_flags, **_version_kwargs)
@@ -356,7 +372,7 @@ def hunspellchecker_argument_parser(
         )
         _languages_kwargs.update(languages_kwargs)
 
-        if isinstance(languages_name_or_flags, str):
+        if isinstance(languages_name_or_flags, str):  # pragma: no cover
             languages_name_or_flags = [languages_name_or_flags]
 
         parser.add_argument(*languages_name_or_flags, **_languages_kwargs)
@@ -374,7 +390,7 @@ def hunspellchecker_argument_parser(
         }
         _personal_dicts_kwargs.update(personal_dicts_kwargs)
 
-        if isinstance(personal_dicts_name_or_flags, str):
+        if isinstance(personal_dicts_name_or_flags, str):  # pragma: no cover
             personal_dicts_name_or_flags = [personal_dicts_name_or_flags]
 
         parser.add_argument(*personal_dicts_name_or_flags, **_personal_dicts_kwargs)
@@ -391,7 +407,7 @@ def hunspellchecker_argument_parser(
         }
         _encoding_kwargs.update(encoding_kwargs)
 
-        if isinstance(encoding_name_or_flags, str):
+        if isinstance(encoding_name_or_flags, str):  # pragma: no cover
             encoding_name_or_flags = [encoding_name_or_flags]
 
         parser.add_argument(*encoding_name_or_flags, **_encoding_kwargs)
@@ -409,7 +425,7 @@ def hunspellchecker_argument_parser(
         }
         _digits_are_words_kwargs.update(digits_are_words_kwargs)
 
-        if isinstance(digits_are_words_name_or_flags, str):
+        if isinstance(digits_are_words_name_or_flags, str):  # pragma: no cover
             digits_are_words_name_or_flags = [digits_are_words_name_or_flags]
 
         parser.add_argument(*digits_are_words_name_or_flags, **_digits_are_words_kwargs)
@@ -427,7 +443,7 @@ def hunspellchecker_argument_parser(
         }
         _words_not_contain_digits_kwargs.update(words_not_contain_digits_kwargs)
 
-        if isinstance(words_not_contain_digits_name_or_flags, str):
+        if isinstance(words_not_contain_digits_name_or_flags, str):  # pragma: no cover
             words_not_contain_digits_name_or_flags = [
                 words_not_contain_digits_name_or_flags
             ]
@@ -449,7 +465,7 @@ def hunspellchecker_argument_parser(
         }
         _words_not_startswith_dash_kwargs.update(words_not_startswith_dash_kwargs)
 
-        if isinstance(words_not_startswith_dash_name_or_flags, str):
+        if isinstance(words_not_startswith_dash_name_or_flags, str):  # pragma: no cover
             words_not_startswith_dash_name_or_flags = [
                 words_not_startswith_dash_name_or_flags
             ]
@@ -472,7 +488,7 @@ def hunspellchecker_argument_parser(
         }
         _words_not_endswith_dash_kwargs.update(words_not_endswith_dash_kwargs)
 
-        if isinstance(words_not_endswith_dash_name_or_flags, str):
+        if isinstance(words_not_endswith_dash_name_or_flags, str):  # pragma: no cover
             words_not_endswith_dash_name_or_flags = [
                 words_not_endswith_dash_name_or_flags
             ]
@@ -494,7 +510,7 @@ def hunspellchecker_argument_parser(
         }
         _words_not_contain_dash_kwargs.update(words_not_contain_dash_kwargs)
 
-        if isinstance(words_not_contain_dash_name_or_flags, str):
+        if isinstance(words_not_contain_dash_name_or_flags, str):  # pragma: no cover
             words_not_contain_dash_name_or_flags = [
                 words_not_contain_dash_name_or_flags
             ]
@@ -503,6 +519,31 @@ def hunspellchecker_argument_parser(
             *words_not_contain_dash_name_or_flags, **_words_not_contain_dash_kwargs
         )
 
+    if words_not_contain_two_upper:
+        _words_not_contain_two_upper_kwargs = {
+            "action": "store_false",
+            "required": False,
+            "dest": "words_can_contain_two_upper",
+            "default": True,
+            "help": (
+                "Words containing two or more uppercase letters will not be"
+                " checked for possible mispelling errors."
+            ),
+        }
+        _words_not_contain_two_upper_kwargs.update(words_not_contain_two_upper_kwargs)
+
+        if isinstance(
+            words_not_contain_two_upper_name_or_flags, str
+        ):  # pragma: no cover
+            words_not_contain_two_upper_name_or_flags = [
+                words_not_contain_two_upper_name_or_flags
+            ]
+
+        parser.add_argument(
+            *words_not_contain_two_upper_name_or_flags,
+            **_words_not_contain_two_upper_kwargs,
+        )
+
     if no_include_filename:
         _no_include_filename_kwargs = {
             "action": "store_false",
@@ -513,7 +554,7 @@ def hunspellchecker_argument_parser(
         }
         _no_include_filename_kwargs.update(no_include_filename_kwargs)
 
-        if isinstance(no_include_filename_name_or_flags, str):
+        if isinstance(no_include_filename_name_or_flags, str):  # pragma: no cover
             no_include_filename_name_or_flags = [no_include_filename_name_or_flags]
 
         parser.add_argument(
@@ -530,7 +571,7 @@ def hunspellchecker_argument_parser(
         }
         _no_include_line_number_kwargs.update(no_include_line_number_kwargs)
 
-        if isinstance(no_include_line_number_name_or_flags, str):
+        if isinstance(no_include_line_number_name_or_flags, str):  # pragma: no cover
             no_include_line_number_name_or_flags = [
                 no_include_line_number_name_or_flags
             ]
@@ -549,7 +590,7 @@ def hunspellchecker_argument_parser(
         }
         _no_include_word_kwargs.update(no_include_word_kwargs)
 
-        if isinstance(no_include_word_name_or_flags, str):
+        if isinstance(no_include_word_name_or_flags, str):  # pragma: no cover
             no_include_word_name_or_flags = [no_include_word_name_or_flags]
 
         parser.add_argument(*no_include_word_name_or_flags, **_no_include_word_kwargs)
@@ -567,7 +608,9 @@ def hunspellchecker_argument_parser(
         }
         _no_include_word_line_index_kwargs.update(no_include_word_line_index_kwargs)
 
-        if isinstance(no_include_word_line_index_name_or_flags, str):
+        if isinstance(
+            no_include_word_line_index_name_or_flags, str
+        ):  # pragma: no cover
             no_include_word_line_index_name_or_flags = [
                 no_include_word_line_index_name_or_flags
             ]
@@ -590,7 +633,7 @@ def hunspellchecker_argument_parser(
         }
         _include_line_kwargs.update(include_line_kwargs)
 
-        if isinstance(include_line_name_or_flags, str):
+        if isinstance(include_line_name_or_flags, str):  # pragma: no cover
             include_line_name_or_flags = [include_line_name_or_flags]
 
         parser.add_argument(*include_line_name_or_flags, **_include_line_kwargs)
@@ -608,7 +651,7 @@ def hunspellchecker_argument_parser(
         }
         _include_text_kwargs.update(include_text_kwargs)
 
-        if isinstance(include_text_name_or_flags, str):
+        if isinstance(include_text_name_or_flags, str):  # pragma: no cover
             include_text_name_or_flags = [include_text_name_or_flags]
 
         parser.add_argument(*include_text_name_or_flags, **_include_text_kwargs)
@@ -623,7 +666,7 @@ def hunspellchecker_argument_parser(
         }
         _include_error_number_kwargs.update(include_error_number_kwargs)
 
-        if isinstance(include_error_number_name_or_flags, str):
+        if isinstance(include_error_number_name_or_flags, str):  # pragma: no cover
             include_error_number_name_or_flags = [include_error_number_name_or_flags]
 
         parser.add_argument(
@@ -643,7 +686,7 @@ def hunspellchecker_argument_parser(
         }
         _include_near_misses_kwargs.update(include_near_misses_kwargs)
 
-        if isinstance(include_near_misses_name_or_flags, str):
+        if isinstance(include_near_misses_name_or_flags, str):  # pragma: no cover
             include_near_misses_name_or_flags = [include_near_misses_name_or_flags]
 
         parser.add_argument(
